'use client';
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var React = require('react');
var styled = require('styled-components');
var sanitizeHtml = require('sanitize-html');
var uiUtils = require('@bolttech/ui-utils');
var defaultTheme = require('@bolttech/default-theme');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var styled__default = /*#__PURE__*/_interopDefaultLegacy(styled);
var sanitizeHtml__default = /*#__PURE__*/_interopDefaultLegacy(sanitizeHtml);

const ScreenSizes = {
    LG: {
        min: 1440,
    },
    MD: {
        max: 1439,
        min: 768,
    },
    SM: {
        max: 767,
        min: 414,
    },
    XS: {
        max: 413,
    },
};
const MediaQueries = {
    LG: `(min-width: ${ScreenSizes.LG.min}px)`,
    MD: `(min-width: ${ScreenSizes.MD.min}px) and (max-width: ${ScreenSizes.MD.max}px)`,
    SM: `(min-width: ${ScreenSizes.SM.min}px) and (max-width: ${ScreenSizes.SM.max}px)`,
    XS: `(max-width: ${ScreenSizes.XS.max}px)`,
};

const PREFIX_REGEX = /([a-z]{2}:)/g;
/**
 * Generates CSS border styles based on utility class names found within the `className` parameter.
 * It utilizes regex patterns to identify border width and color classes, then maps these to corresponding
 * CSS rules based on the provided theme settings.
 *
 * Border width and color utility classes are expected to follow specific naming conventions, and
 * this function handles both responsive prefixes and different border sides.
 *
 * @param {CssType} param0 - An object containing the theme and className properties.
 * @returns {string} The generated CSS string for border styles.
 *
 * @example
 * // Assuming the theme has predefined border widths and colors
 * generateBorderStyles({ theme, className: 'bt-2 b-color-primary' });
 * // -> "border-top: 2px solid; border-color: #007bff;"
 */
const generateBorderStyles = ({ theme, className }) => {
    if (className && className.length > 0) {
        const BORDER_WIDTH_REGEX = /\b([a-z]{2}:)?\bb(t|b|l|r)?-([0-9]|(s|m|l|d|x|g)){1,3}/g;
        const BORDER_COLOR_REGEX = /\b([a-z]{2}:)?\bb(t|b|l|r)?-color-([A-z]|[0-9])+/g;
        const borderClasses = className.match(BORDER_WIDTH_REGEX);
        const borderColorClasses = className.match(BORDER_COLOR_REGEX);
        const propId = {
            t: 'border-top',
            b: 'border-bottom',
            l: 'border-left',
            r: 'border-right',
        };
        const colorPropId = {
            t: 'border-top-color',
            b: 'border-bottom-color',
            l: 'border-left-color',
            r: 'border-right-color',
        };
        const cssBorderWidth = borderClasses
            ?.map((classFound) => {
            const havePrefix = classFound.match(PREFIX_REGEX);
            const classNameWithoutPrefix = classFound.replace(PREFIX_REGEX, '');
            const borderSpecs = classNameWithoutPrefix.split('-');
            // Check if border variant exists
            if (borderSpecs[1].toUpperCase() in theme.spacing.borderWidth) {
                let rule = '';
                if (borderSpecs[0].length > 1) {
                    rule = `${propId[borderSpecs[0][1]]}: ${theme.spacing.borderWidth[borderSpecs[1].toUpperCase()]} solid;`;
                }
                else {
                    rule = `border: ${theme.spacing.borderWidth[borderSpecs[1].toUpperCase()]} solid;`;
                }
                if (havePrefix?.length) {
                    return `
              @media ${MediaQueries[havePrefix[0].replace(':', '').toUpperCase()]} {
                ${rule}
              }
            `;
                }
                return rule;
            }
            return '';
        })
            .join('');
        const cssBorderColor = borderColorClasses
            ?.map((classFound) => {
            const havePrefix = classFound.match(PREFIX_REGEX);
            const classNameWithoutPrefix = classFound.replace(PREFIX_REGEX, '');
            const borderSpecs = classNameWithoutPrefix.split('-');
            // Check if border variant exists
            if (borderSpecs[2] in theme.colors.border) {
                let rule = '';
                if (borderSpecs[0].length > 1) {
                    rule = `${colorPropId[borderSpecs[0][1]]}: ${theme.colors.border[borderSpecs[2]]};`;
                }
                else {
                    rule = `border-color: ${theme.colors.border[borderSpecs[2]]};`;
                }
                if (havePrefix?.length) {
                    return `
              @media ${MediaQueries[havePrefix[0].replace(':', '').toUpperCase()]} {
                ${rule}
              }
            `;
                }
                return rule;
            }
            return '';
        })
            .join('');
        return styled.css `
      ${cssBorderWidth}
      ${cssBorderColor}
    `;
    }
    return undefined;
};
/**
 * Generates CSS box-shadow styles based on utility class names found within the `className` parameter.
 * It utilizes a regex pattern to identify box-shadow level classes, then maps these to corresponding
 * CSS rules based on the provided theme settings.
 *
 * Box-shadow level utility classes are expected to follow a specific naming convention,
 * and this function also handles responsive prefixes.
 *
 * @param {CssType} param0 - An object containing the theme and className properties.
 * @returns {string} The generated CSS string for box-shadow styles.
 *
 * @example
 * // Assuming the theme has predefined box-shadow levels
 * generateBoxShadowStyles({ theme, className: 'bs-lvl2' });
 * // -> "box-shadow: 0px 4px 6px -1px rgba(0,0,0,0.1),0px 2px 4px -1px rgba(0,0,0,0.06);"
 */
const generateBoxShadowStyles = ({ theme, className }) => {
    const BOX_SHADOW_REGEX = /\b([a-z]{2}:)?\bbs-lvl[0-9]+/g;
    const boxShadowClassesFound = className?.match(BOX_SHADOW_REGEX);
    if (boxShadowClassesFound && boxShadowClassesFound.length > 0) {
        return boxShadowClassesFound.map((classFound) => {
            const havePrefix = classFound.match(PREFIX_REGEX);
            const shadowClassNameSplitted = classFound.split('-');
            const rule = `box-shadow: ${theme.effects.shadow[shadowClassNameSplitted[1]]};`;
            if (havePrefix?.length) {
                return `
          @media ${MediaQueries[havePrefix[0].replace(':', '').toUpperCase()]} {
            ${rule}
          }
        `;
            }
            return rule;
        });
    }
    return undefined;
};
const generateBorderRadiusStyles = ({ theme, className }) => {
    const BORDER_RADIUS_REGEX = /\b([a-z]{2}:)?\bb-radius-([A-z]|[0-9])+/g;
    const borderRadiusClassesFound = className?.match(BORDER_RADIUS_REGEX);
    if (borderRadiusClassesFound && borderRadiusClassesFound.length > 0) {
        return borderRadiusClassesFound.map((classFound) => {
            const havePrefix = classFound.match(PREFIX_REGEX);
            const borderRadiuslassNameSplitted = classFound.split('-');
            const rule = `border-radius: ${theme.spacing.borderRadius[borderRadiuslassNameSplitted[2]]};`;
            if (havePrefix?.length) {
                return `
          @media ${MediaQueries[havePrefix[0].replace(':', '').toUpperCase()]} {
            ${rule}
          }
        `;
            }
            return rule;
        });
    }
    return undefined;
};
const Container = styled__default["default"].div `
  ${generateBorderStyles}
  ${generateBoxShadowStyles}
  ${generateBorderRadiusStyles}
  &.grid {
    max-width: 1440px;
    width: 100%;

    ${({ $removeGridPadding }) => !$removeGridPadding &&
    styled.css `
        padding-left: ${({ theme }) => theme.tokens.flexbox.S};
        padding-right: ${({ theme }) => theme.tokens.flexbox.S};

        @media ${MediaQueries.SM} {
          padding-left: ${({ theme }) => theme.tokens.flexbox.L};
          padding-right: ${({ theme }) => theme.tokens.flexbox.L};
        }

        @media ${MediaQueries.MD} {
          padding-left: ${({ theme }) => theme.tokens.flexbox['2XL']};
          padding-right: ${({ theme }) => theme.tokens.flexbox['2XL']};
        }

        @media ${MediaQueries.LG} {
          padding-left: ${({ theme }) => theme.tokens.flexbox['3XL']};
          padding-right: ${({ theme }) => theme.tokens.flexbox['3XL']};
        }
      `}

    ${({ $removeGridGap }) => !$removeGridGap &&
    styled.css `
        column-gap: ${({ theme }) => theme.tokens.flexbox.XS};

        @media ${MediaQueries.SM} {
          column-gap: ${({ theme }) => theme.tokens.flexbox.S};
        }

        @media ${MediaQueries.MD} {
          column-gap: ${({ theme }) => theme.tokens.flexbox.M};
        }

        @media ${MediaQueries.LG} {
          column-gap: ${({ theme }) => theme.tokens.flexbox.M};
        }
      `}
  }

  ${({ $sizes }) => !!$sizes &&
    `
    flex: 0 1 ${$sizes.xs}%;

    @media ${MediaQueries.SM} {
      flex: 0 1 ${$sizes.sm}%;
    }

    @media ${MediaQueries.MD} {
      flex: 0 1 ${$sizes.md}%;
    }

    @media ${MediaQueries.LG} {
      flex: 0 1 ${$sizes.lg}%;
    }
  `}
`;

const Box = React.forwardRef(({ className, removeGridGap, removeGridPadding, sizes, children, onClick }, ref) => {
    const formatSizes = () => {
        const requiredKeys = ['xs', 'sm', 'md', 'lg'];
        if (sizes) {
            const finalSizes = sizes;
            const checkAllKeys = requiredKeys.every((key) => key in finalSizes && finalSizes[key]);
            return checkAllKeys ? sizes : undefined;
        }
        return undefined;
    };
    return (jsxRuntime.jsx(Container, { ref: ref, className: Array.isArray(className) ? className.join(' ').trim() : className, "$removeGridPadding": removeGridPadding, "$removeGridGap": removeGridGap, "$sizes": formatSizes(), onClick: onClick, children: children }));
});
Box.displayName = 'BoxContainer';

const CenterContainer = styled__default["default"].div `
  display: flex;
  max-width: 100vw;
  width: 100%;

  & > div {
    width: inherit;
    max-width: 1440px;
    margin: 0 auto;
  }
`;

var Center = React.forwardRef((props, ref) => {
    return (jsxRuntime.jsx(CenterContainer, { ref: ref, className: props.className, children: jsxRuntime.jsx("div", { children: props.children }) }));
});

const calculateChildrens = ($size) => {
    const childrens = Math.round(100 / parseInt($size.replace('%', '')));
    return childrens === 1 ? childrens + 1 : childrens;
};
const getDisplay = ($size) => styled.css `
  display: ${$size === '0%' ? 'none' : 'block'};
  ${$size === '0%' ? '.flex { display: none; }' : '.flex { display: flex; }'};
`;
const ColumnContainer = styled__default["default"].div `
  --childrens-xs: ${({ $size }) => calculateChildrens($size.xs)};
  --childrens-sm: ${({ $size }) => calculateChildrens($size.sm)};
  --childrens-md: ${({ $size }) => calculateChildrens($size.md)};
  --childrens-lg: ${({ $size }) => calculateChildrens($size.lg)};

  width: ${({ $size, theme }) => $size.xs !== '100%'
    ? `calc(${$size.xs} - (${theme.tokens.flexbox.XS} * (var(--childrens-xs) - 1)) / var(--childrens-xs))`
    : '100%'};

  ${({ $size }) => getDisplay($size.xs)};

  @media ${MediaQueries.SM} {
    width: ${({ $size, theme }) => $size.sm !== '100%'
    ? `calc(${$size.sm} - (${theme.tokens.flexbox.S} * (var(--childrens-sm) - 1)) / var(--childrens-sm))`
    : '100%'};

    ${({ $size }) => getDisplay($size.sm)};
  }

  @media ${MediaQueries.MD} {
    width: ${({ $size, theme }) => $size.md !== '100%'
    ? `calc(${$size.md} - (${theme.tokens.flexbox.M} * (var(--childrens-md) - 1)) / var(--childrens-md))`
    : '100%'};

    ${({ $size }) => getDisplay($size.md)};
  }

  @media ${MediaQueries.LG} {
    width: ${({ $size, theme }) => $size.lg !== '100%'
    ? `calc(${$size.lg} - (${theme.tokens.flexbox.M} * (var(--childrens-lg) - 1)) / var(--childrens-lg))`
    : '100%'};

    ${({ $size }) => getDisplay($size.lg)};
  }
`;

const Column = React.forwardRef(({ children, size, className, ...rest }, ref) => {
    return (jsxRuntime.jsx(ColumnContainer, { ...rest, ref: ref, className: className, "$size": size, children: children }));
});

const RowContainer = styled__default["default"].div `
  display: flex;
  flex-wrap: wrap;
  max-width: 1440px;
  gap: ${({ theme }) => theme.tokens.flexbox.XS};

  @media ${MediaQueries.SM} {
    gap: ${({ theme }) => theme.tokens.flexbox.S};
  }

  @media ${MediaQueries.MD} {
    gap: ${({ theme }) => theme.tokens.flexbox.M};
  }

  @media ${MediaQueries.LG} {
    gap: ${({ theme }) => theme.tokens.flexbox.M};
  }

  ${({ $center }) => $center &&
    styled.css `
      margin: 0 auto;
    `}

  ${({ $fullHeight }) => $fullHeight &&
    styled.css `
      height: 100%;
    `}

  ${({ $fullWidth }) => !$fullWidth &&
    styled.css `
      padding-left: ${({ theme }) => theme.tokens.flexbox.S};
      padding-right: ${({ theme }) => theme.tokens.flexbox.S};

      @media ${MediaQueries.SM} {
        padding-left: ${({ theme }) => theme.tokens.flexbox.L};
        padding-right: ${({ theme }) => theme.tokens.flexbox.L};
      }

      @media ${MediaQueries.MD} {
        padding-left: ${({ theme }) => theme.tokens.flexbox['2XL']};
        padding-right: ${({ theme }) => theme.tokens.flexbox['2XL']};
      }

      @media ${MediaQueries.LG} {
        padding-left: ${({ theme }) => theme.tokens.flexbox['3XL']};
        padding-right: ${({ theme }) => theme.tokens.flexbox['3XL']};
      }
    `}
`;

const Row = React.forwardRef(({ className, children, fullWidth = false, fullHeight = false, center = false, ...rest }, ref) => {
    return (jsxRuntime.jsx(RowContainer, { ...rest, ref: ref, "$fullWidth": fullWidth, "$fullHeight": fullHeight, "$center": center, className: className, children: children }));
});

/* eslint-disable @typescript-eslint/no-explicit-any */
const cssTypography = ({ theme, $align, $type, $variant, }) => styled.css `
  text-align: ${$align ? $align : 'left'};
  font-weight: ${theme.typography.mobile[$type][$variant].fontWeight};
  line-height: ${theme.typography.mobile[$type][$variant].lineHeight};
  font-size: ${theme.typography.mobile[$type][$variant].fontSize};
  letter-spacing: ${theme.typography.mobile[$type][$variant].letterSpacing};

  ${`@media only screen and (min-width: ${ScreenSizes.XS.max}px)`} {
    font-weight: ${theme.typography.desktop[$type][$variant].fontWeight};
    line-height: ${theme.typography.desktop[$type][$variant].lineHeight};
    font-size: ${theme.typography.desktop[$type][$variant].fontSize};
    letter-spacing: ${theme.typography.desktop[$type][$variant].letterSpacing};
  }

  a {
    font-weight: 700;
    color: inherit;
  }
`;
const TyporaphyHeading = styled__default["default"].h1 `
  ${cssTypography}
`;
const TyporaphyLabel = styled__default["default"].label `
  ${cssTypography}
`;
const TyporaphyParagraph = styled__default["default"].p `
  ${cssTypography}
`;
const TyporaphySpan = styled__default["default"].span `
  ${cssTypography}
`;

const sanitizerConfig = {
    ...sanitizeHtml__default["default"].defaults,
    allowedTags: sanitizeHtml__default["default"].defaults.allowedTags.concat(['img']),
    allowedAttributes: {
        ...sanitizeHtml__default["default"].defaults.allowedAttributes,
        '*': ['class', 'disabled'],
    },
};
const elements = {
    headings: {
        h0: 'h1',
        h1: 'h1',
        h1Light: 'h1',
        h2: 'h2',
        h3: 'h3',
        h4: 'h4',
    },
    body: 'p',
    label: 'label',
    input: 'label',
    button: 'label',
};
const allowedProps = {
    blank: {
        target: '_blank',
    },
    download: {
        download: true,
    },
};
const Typography = React.forwardRef(({ className, children, type = 'body', variant = 'primary', text, align, dataTestId, htmlFor, id, ...props }, ref) => {
    const initialValue = children || text;
    const value = typeof initialValue === 'object' ? initialValue.join('') : initialValue;
    let linksMatched = [];
    let formatForReplace = '';
    let currentLink = 0;
    let links = [];
    if (value && typeof value === 'string') {
        const regex = new RegExp(/(\[[0-9A-Za-zÀ-ÖØ-öø-ÿ ~+.!#%^&+@:/()*$_?=`´’"'|/\\-]+\](\([\w0-9+.!#%^&+@:/*$_?=`´’"'|/\\-]+\))(\((blank|download)\))?)+/g);
        linksMatched = value?.match(regex) || [];
        formatForReplace = value?.replace(regex, '${replace}');
        links = linksMatched?.map((matched, index) => {
            const text = matched.match(/\[[0-9A-zÀ-ÖØ-öø-ÿ +.!#%^&+@:/()*$_?=`´’"'|/\\-]+\]/g)?.[0] || '';
            const formattedText = text.slice(1, -1);
            const link = matched.replace(text, '');
            const linkFormatted = link.replace(text, '').substring(link.indexOf('(') + 1, link.indexOf(')'));
            const linkProps = link.substring(link.lastIndexOf('(') + 1, link.lastIndexOf(')'));
            return (jsxRuntime.jsx("a", { href: linkFormatted, rel: "noopener", ...allowedProps[linkProps], ...uiUtils.applyDataAttributes(props, `link-${index + 1}`), children: formattedText }));
        });
    }
    const renderTypography = (localChildren) => {
        const elSelected = elements[type][variant] ||
            elements[type] ||
            'span';
        switch (elSelected) {
            case 'p':
                return (jsxRuntime.jsx(TyporaphyParagraph, { className: className, "$type": type, "$variant": variant, "$align": align, ref: ref, "data-testid": dataTestId, id: id, ...(typeof localChildren === 'string'
                        ? { dangerouslySetInnerHTML: { __html: localChildren } }
                        : { children: localChildren }), ...uiUtils.applyDataAttributes(props) }));
            case 'label':
                return (jsxRuntime.jsx(TyporaphyLabel, { className: className, "$type": type, "$variant": variant, "$align": align, ref: ref, "data-testid": dataTestId, htmlFor: htmlFor, id: id, ...(typeof localChildren === 'string'
                        ? { dangerouslySetInnerHTML: { __html: localChildren } }
                        : { children: localChildren }), ...uiUtils.applyDataAttributes(props) }));
            case 'span':
                return (jsxRuntime.jsx(TyporaphySpan, { className: className, "$type": type, "$variant": variant, "$align": align, ref: ref, "data-testid": dataTestId, id: id, ...(typeof localChildren === 'string'
                        ? { dangerouslySetInnerHTML: { __html: localChildren } }
                        : { children: localChildren }), ...uiUtils.applyDataAttributes(props) }));
            default:
                return (jsxRuntime.jsx(TyporaphyHeading, { as: elSelected, className: className, "$type": type, "$variant": variant, "$align": align, ref: ref, "data-testid": dataTestId, id: id, ...(typeof localChildren === 'string'
                        ? { dangerouslySetInnerHTML: { __html: localChildren } }
                        : { children: localChildren }), ...uiUtils.applyDataAttributes(props) }));
        }
    };
    return links && links?.length
        ? renderTypography(formatForReplace?.split(/(\${replace})/).map((word, index) => {
            return (jsxRuntime.jsx(React__default["default"].Fragment, { children: word === '${replace}' ? links && links[currentLink++] : word }, index));
        }))
        : renderTypography(sanitizeHtml__default["default"](value, sanitizerConfig));
});

/**
 * An array representing a range of sizes from 0 to 100.
 */
new Array(101).fill(0);

const UtilitaryClasses = styled.createGlobalStyle `
  ${styled.css `
    :root {
      ${(props) => props.theme.styles.style}
    }
  `}
`;
const BolttechThemeProvider = ({ children, theme = defaultTheme.bolttechTheme }) => (jsxRuntime.jsxs(styled.ThemeProvider, { theme: theme, children: [jsxRuntime.jsx(UtilitaryClasses, { theme: theme }), children] }));

exports.BolttechThemeProvider = BolttechThemeProvider;
exports.Box = Box;
exports.Center = Center;
exports.Column = Column;
exports.MediaQueries = MediaQueries;
exports.Row = Row;
exports.ScreenSizes = ScreenSizes;
exports.Typography = Typography;
